==> smallrye-jwt-2.0.13.redhat-00002-sources.jar: io/smallrye/jwt/auth/principal/DefaultJWTParser.java <==
/*
 *   Copyright 2019 Red Hat, Inc, and individual contributors.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package io.smallrye.jwt.auth.principal;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;

import org.eclipse.microprofile.jwt.JsonWebToken;

/**
 * A default implementation of {@link JWTParser}.
 */
@ApplicationScoped
public class DefaultJWTParser implements JWTParser {

    @Inject
    private JWTAuthContextInfo authContextInfo;

    private volatile JWTCallerPrincipalFactory callerPrincipalFactory;

    public JsonWebToken parse(final String bearerToken) throws ParseException {
        return getcallerPrincipalFactory().parse(bearerToken, authContextInfo);
    }

    private JWTCallerPrincipalFactory getcallerPrincipalFactory() {
        if (callerPrincipalFactory == null) {
            synchronized (this) {
                if (callerPrincipalFactory == null) {
                    callerPrincipalFactory = JWTCallerPrincipalFactory.instance();
                }
            }
        }
        return callerPrincipalFactory;
    }

}

==> smallrye-jwt-2.1.2.redhat-00002-sources.jar: io/smallrye/jwt/auth/principal/DefaultJWTParser.java <==
/*
 *   Copyright 2019 Red Hat, Inc, and individual contributors.
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 *
 */
package io.smallrye.jwt.auth.principal;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;

import org.eclipse.microprofile.jwt.JsonWebToken;

/**
 * A default implementation of {@link JWTParser}.
 */
@ApplicationScoped
public class DefaultJWTParser implements JWTParser {

    @Inject
    private JWTAuthContextInfo authContextInfo;

    private volatile JWTCallerPrincipalFactory callerPrincipalFactory;

    public DefaultJWTParser() {
    }

    public DefaultJWTParser(JWTAuthContextInfo authContextInfo) {
        this.authContextInfo = authContextInfo;
    }

    public JsonWebToken parse(final String bearerToken) throws ParseException {
        return getCallerPrincipalFactory().parse(bearerToken, authContextInfo);
    }

    private JWTCallerPrincipalFactory getCallerPrincipalFactory() {
        if (callerPrincipalFactory == null) {
            synchronized (this) {
                if (callerPrincipalFactory == null) {
                    callerPrincipalFactory = JWTCallerPrincipalFactory.instance();
                }
            }
        }
        return callerPrincipalFactory;
    }

}
